@@ -86,7 +86,7 @@ class OnBoardVNF(forms.SelfHandlingForm):
     def handle(self, request, data):
         try:
             toscal = data['tosca']
-            tosca_arg = { 'vnfd': {'vnfd': toscal}}
+            tosca_arg = { 'vnfd': {'attributes': {'vnfd': toscal}}}
             vnfd_instance = api.tacker.create_vnfd(request, tosca_arg)
             messages.success(request,
                              _('VNF Catalog entry %s has been created.') % vnfd_instance['vnfd']['name'])
